Flask-Multipass
===============

.. image:: https://readthedocs.org/projects/flask-multipass/badge/?version=latest
    :target: https://flask-multipass.readthedocs.org/
.. image:: https://travis-ci.org/indico/flask-multipass.svg
    :target: https://travis-ci.org/indico/flask-multipass
.. image:: https://coveralls.io/repos/indico/flask-multipass/badge.svg
    :target: https://coveralls.io/r/indico/flask-multipass

Flask-Multipass is an extension that provides a user authentication
system for Flask which can use multiple backends (such as local users,
LDAP and OAuth) simultaneously.
